summaryrefslogtreecommitdiffstats
path: root/tools/designer/designer/resource.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/designer/designer/resource.cpp')
-rw-r--r--tools/designer/designer/resource.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tools/designer/designer/resource.cpp b/tools/designer/designer/resource.cpp
index 257f4e6..cb1c39a 100644
--- a/tools/designer/designer/resource.cpp
+++ b/tools/designer/designer/resource.cpp
@@ -1756,7 +1756,7 @@ void Resource::saveProperty( QObject *w, const QString &name, const QVariant &va
break;
}
default:
- qWarning( "saving the property %s of type %d not supported yet", name.latin1(), (int)t );
+ tqWarning( "saving the property %s of type %d not supported yet", name.latin1(), (int)t );
}
}
@@ -1803,7 +1803,7 @@ QObject *Resource::createObject( const QDomElement &e, QWidget *parent, QLayout*
bool isPlugin =
WidgetDatabase::isCustomPluginWidget( WidgetDatabase::idFromClassName( parentClassName ) );
if ( isPlugin )
- qWarning( "####### loading custom container widgets without page support not implemented!" );
+ tqWarning( "####### loading custom container widgets without page support not implemented!" );
// ### TODO loading for custom container widgets without pages
#endif
if ( !className.isNull() ) {
@@ -2367,9 +2367,9 @@ void Resource::saveImageData( const QImage &img, QTextStream &ts, int indent )
QByteArray bazip = ba;
int i = 0;
if (compress) {
- bazip = qCompress( ba );
+ bazip = tqCompress( ba );
format += ".GZ";
// The first 4 bytes in qCompress() are the length of the unzipped
// format. The XPM.GZ format does not use these.
i = 4;
}
@@ -2367,9 +2367,9 @@ void Resource::saveImageData( const QImage &img, QTextStream &ts, int indent )
format += ".GZ";
- // The first 4 bytes in qCompress() are the length of the unzipped
+ // The first 4 bytes in tqCompress() are the length of the unzipped
// format. The XPM.GZ format does not use these.
i = 4;